==> flink-runtime_2.11-1.6.2-sources.jar: org/apache/flink/runtime/rest/handler/legacy/files/WebContentHandlerSpecification.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.handler.legacy.files;

import org.apache.flink.runtime.rest.HttpMethodWrapper;
import org.apache.flink.runtime.rest.handler.RestHandlerSpecification;

/**
 * Rest handler specification for the web content handler.
 */
public final class WebContentHandlerSpecification implements RestHandlerSpecification {

	private static final WebContentHandlerSpecification INSTANCE = new WebContentHandlerSpecification();

	private WebContentHandlerSpecification() {}

	@Override
	public HttpMethodWrapper getHttpMethod() {
		return HttpMethodWrapper.GET;
	}

	@Override
	public String getTargetRestEndpointURL() {
		return "/:*";
	}

	public static WebContentHandlerSpecification getInstance() {
		return INSTANCE;
	}
}

==> flink-runtime_2.12-1.13.1-sources.jar: org/apache/flink/runtime/rest/handler/legacy/files/WebContentHandlerSpecification.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.handler.legacy.files;

import org.apache.flink.runtime.rest.HttpMethodWrapper;
import org.apache.flink.runtime.rest.handler.RestHandlerSpecification;

/** Rest handler specification for the web content handler. */
public final class WebContentHandlerSpecification implements RestHandlerSpecification {

    private static final WebContentHandlerSpecification INSTANCE =
            new WebContentHandlerSpecification();

    private WebContentHandlerSpecification() {}

    @Override
    public HttpMethodWrapper getHttpMethod() {
        return HttpMethodWrapper.GET;
    }

    @Override
    public String getTargetRestEndpointURL() {
        return "/:*";
    }

    public static WebContentHandlerSpecification getInstance() {
        return INSTANCE;
    }
}
